StatState

Enum StatState 

pub(crate) enum StatState {
    Clean,
    Dirty,
    Reset,
}
This enum is used to decide if a stat is dirty or not, and whether it should be serialized or not.

This is done so that during a domain transfer, stats reset to zero from a previous domain to update the client are not serialized to the next.

Variants



Clean

The stat is clean (not dirty), so no update will be sent from this stat until the counter changes value. The stat will be persisted.



Dirty

This stat is dirty, so the next time stats are queried by the client, its update will get sent to the client. The stat will be persisted.



Reset

This stat was reset upon transferring domains, so its update will get sent to the client. The stat will not be persisted.